@@ -42,10 +42,18 @@ bool CnxnInfo_init()
 static PyObject* GetHash(PyObject* p)
 {
 #if PY_MAJOR_VERSION >= 3
-    Object bytes(PyUnicode_EncodeUTF8(PyUnicode_AS_UNICODE(p), PyUnicode_GET_SIZE(p), 0));
+    Object bytes(PyUnicode_AsUTF8String(p));
     if (!bytes)
         return 0;
     p = bytes.Get();
+#else
+    Object bytes(PyUnicode_Check(p) ? PyUnicode_EncodeUTF8(PyUnicode_AS_UNICODE(p), PyUnicode_GET_SIZE(p), 0) : 0);
+    if (PyUnicode_Check(p))
+    {
+        if (!bytes)
+            return 0;
+        p = bytes.Get();
+    }
 #endif
 
     Object hash(PyObject_CallMethod(hashlib, "new", "s", "sha1"));
