@@ -45,6 +45,10 @@ struct Connection
     // The connection timeout in seconds.
     long timeout;
 
+    // Pointer connection attributes may require that the pointed-to object be kept
+    // valid until some unspecified time in the future, so keep them here for now.
+    PyObject* attrs_before;
+
     TextEnc sqlchar_enc;        // encoding used when reading SQL_CHAR data
     TextEnc sqlwchar_enc;       // encoding used when reading SQL_WCHAR data
     TextEnc unicode_enc;        // encoding used when writing unicode strings
