@@ -65,7 +65,7 @@ inline bool IsWideType(SQLSMALLINT sqltype)
     return false;
 }
 
-// TODO: Wont pyodbc_free crash if we didn't use pyodbc_realloc.
+// TODO: Won't pyodbc_free crash if we didn't use pyodbc_realloc.
 
 static bool ReadVarColumn(Cursor* cur, Py_ssize_t iCol, SQLSMALLINT ctype, bool& isNull, byte*& pbResult, Py_ssize_t& cbResult)
 {
@@ -631,15 +631,28 @@ static PyObject* GetDataTimestamp(Cursor* cur, Py_ssize_t iCol)
 
     switch (cur->colinfos[iCol].sql_type)
     {
-    case SQL_TYPE_TIME:
-    {
-        int micros = (int)(value.fraction / 1000); // nanos --> micros
-        return PyTime_FromTime(value.hour, value.minute, value.second, micros);
-    }
+		case SQL_TYPE_TIME:
+		{
+			int micros = (int)(value.fraction / 1000); // nanos --> micros
+			return PyTime_FromTime(value.hour, value.minute, value.second, micros);
+		}
 
-    case SQL_TYPE_DATE:
-        return PyDate_FromDate(value.year, value.month, value.day);
+		case SQL_TYPE_DATE:
+			return PyDate_FromDate(value.year, value.month, value.day);
+
+		case SQL_TYPE_TIMESTAMP:
+		{
+			if (value.year < 1)
+			{
+				value.year = 1;
+			}
+			else if (value.year > 9999)
+			{
+				value.year = 9999;
+			}
+		}
     }
+	
 
     int micros = (int)(value.fraction / 1000); // nanos --> micros
 
@@ -862,4 +875,4 @@ PyObject* GetData(Cursor* cur, Py_ssize_t iCol)
 
     return RaiseErrorV("HY106", ProgrammingError, "ODBC SQL type %d is not yet supported.  column-index=%zd  type=%d",
                        (int)pinfo->sql_type, iCol, (int)pinfo->sql_type);
-}
+}
\ No newline at end of file
