@@ -566,6 +566,7 @@ static int PyToCType(Cursor *cur, unsigned char **outbuf, PyObject *cell, ParamI
 
         Py_XDECREF(args);
         Py_XDECREF(scaledDecimal);
+        Py_XDECREF(newDigits);
         Py_XDECREF(cellParts);
 
         pNum->precision = (SQLCHAR)pi->ColumnSize;
@@ -1124,7 +1125,7 @@ static bool GetBufferInfo(Cursor* cur, Py_ssize_t index, PyObject* param, ParamI
     else
     {
         // There are multiple segments, so we'll provide the data at execution time.  Pass the PyObject pointer as
-        // the parameter value which will be pased back to us when the data is needed.  (If we release threads, we
+        // the parameter value which will be passed back to us when the data is needed.  (If we release threads, we
         // need to up the refcount!)
 
         info.ParameterType     = SQL_LONGVARBINARY;
@@ -1376,7 +1377,7 @@ static bool UpdateParamInfo(Cursor* pCursor, Py_ssize_t nIndex, ParamInfo *pInfo
 
   // If the user didn't provide the full array (in case he gave us an array), the above code would
   // set an internal error on the cursor object, as we try to read three values from an array
-  // which may not have as many. This is ok, because we don't really care if the array is not completly
+  // which may not have as many. This is ok, because we don't really care if the array is not completely
   // specified, so we clear the error in case it comes from this. If the error was already present before that
   // we keep it, so the user can handle it.
   if (clearError)
@@ -1952,9 +1953,10 @@ bool ExecuteMulti(Cursor* cur, PyObject* pSql, PyObject* paramArrayObj)
                 if (PyUnicode_Check(objCell))
                 {
                     const TextEnc& enc = cur->cnxn->sqlwchar_enc;
-                    int cb = PyUnicode_GET_DATA_SIZE(objCell) / 2;
-
                     PyObject* bytes = NULL;
+
+#if PY_MAJOR_VERSION < 3
+                    int cb = PyUnicode_GET_DATA_SIZE(objCell) / 2;
                     const Py_UNICODE* source = PyUnicode_AS_UNICODE(objCell);
 
                     switch (enc.optenc)
@@ -1972,11 +1974,28 @@ bool ExecuteMulti(Cursor* cur, PyObject* pSql, PyObject* paramArrayObj)
                         bytes = PyUnicode_EncodeUTF16(source, cb, "strict", BYTEORDER_BE);
                         break;
                     }
-
+#else
+                    switch (enc.optenc)
+                    {
+                    case OPTENC_UTF8:
+                        bytes = PyUnicode_AsUTF8String(objCell);
+                        break;
+                    case OPTENC_UTF16:
+                        bytes = PyUnicode_AsUTF16String(objCell);
+                        break;
+                    case OPTENC_UTF16LE:
+                        bytes = PyUnicode_AsEncodedString(objCell, "utf_16_le", NULL);
+                        break;
+                    case OPTENC_UTF16BE:
+                        bytes = PyUnicode_AsEncodedString(objCell, "utf_16_be", NULL);
+                        break;
+                    }
+#endif
                     if (bytes && PyBytes_Check(bytes))
                     {
                         objCell = bytes;
                     }
+                    //TODO: Raise or clear error when bytes == NULL.
                 }
 
                 szLastFunction = "SQLPutData";
