@@ -611,9 +611,9 @@ class SqlServerTestCase(unittest.TestCase):
         #
         # When we read it out of the database, all we know is that it is XML
         # and we don't know how it was encoded so we don't know how to decode
-        # it.  Since almost everyone treats XML as Unicode nowdays, we're going
+        # it.  Since almost everyone treats XML as Unicode nowadays, we're going
         # to decode XML as Unicode.  Force your XML to Unicode before writing
-        # to the database.  (Otherwise, set a global encoder for the XMl type.)
+        # to the database.  (Otherwise, set a global encoder for the XML type.)
         ascii = 'test'
         val = unicode(ascii)
         self.cursor.execute("create table t1(a xml)")
@@ -1764,8 +1764,9 @@ class SqlServerTestCase(unittest.TestCase):
         self.assertTrue(len(drivers) > 0)
 
         m = re.search('DRIVER={?([^}]+?)}?;', self.connection_string, re.IGNORECASE)
-        current = m.group(1)
-        self.assertTrue(current in drivers)
+        if m:  # issue #1000 - may be testing with DSN= connection
+            current = m.group(1)
+            self.assertTrue(current in drivers)
 
     def test_prepare_cleanup(self):
         # When statement is prepared, it is kept in case the next execute uses the same statement.  This must be
