@@ -69,8 +69,11 @@ class PGTestCase(unittest.TestCase):
         self.cursor = self.cnxn.cursor()
 
         # I've set my test database to use UTF-8 which seems most popular.
-        self.cnxn.setdecoding(pyodbc.SQL_WCHAR, encoding='utf-8')
-        self.cnxn.setencoding(encoding='utf-8')
+        #
+        # disabled re: issue #1004
+        #
+        #self.cnxn.setdecoding(pyodbc.SQL_WCHAR, encoding='utf-8')
+        #self.cnxn.setencoding(encoding='utf-8')
 
         # As of psql 9.5.04 SQLGetTypeInfo returns absurdly small sizes leading
         # to slow writes.  Override them:
@@ -556,7 +559,17 @@ class PGTestCase(unittest.TestCase):
         SQL_MODE_READ_ONLY   = 1
         self.cnxn.set_attr(SQL_ATTR_ACCESS_MODE, SQL_MODE_READ_ONLY)
 
+
     def test_columns(self):
+        driver_version = tuple(
+            int(x) for x in self.cnxn.getinfo(pyodbc.SQL_DRIVER_VER).split(".")
+        )
+
+        def _get_column_size(row):
+            # the driver changed the name of the returned columns in version 13.02.
+            # see https://odbc.postgresql.org/docs/release.html, release 13.02.0000, change 6.
+            return row.column_size if driver_version >= (13, 2, 0) else row.precision
+
         # When using aiohttp, `await cursor.primaryKeys('t1')` was raising the error
         #
         #   Error: TypeError: argument 2 must be str, not None
@@ -572,10 +585,10 @@ class PGTestCase(unittest.TestCase):
         assert row.type_name == 'int4', row.type_name
         row = results['b']
         assert row.type_name == 'varchar'
-        assert row.precision == 3, row.precision
+        assert _get_column_size(row) == 3, _get_column_size(row)
         row = results['xΏz']
         assert row.type_name == 'varchar'
-        assert row.precision == 4, row.precision
+        assert _get_column_size(row) == 4, _get_column_size(row)
 
         # Now do the same, but specifically pass in None to one of the keywords.  Old versions
         # were parsing arguments incorrectly and would raise an error.  (This crops up when
@@ -587,7 +600,7 @@ class PGTestCase(unittest.TestCase):
         assert row.type_name == 'int4', row.type_name
         row = results['b']
         assert row.type_name == 'varchar'
-        assert row.precision == 3
+        assert _get_column_size(row) == 3
 
     def test_cancel(self):
         # I'm not sure how to reliably cause a hang to cancel, so for now we'll settle with
@@ -692,7 +705,7 @@ class PGTestCase(unittest.TestCase):
         self.cnxn.add_output_converter(pyodbc.SQL_WVARCHAR, None)
         value = self.cursor.execute("select v from t1").fetchone()[0]
         self.assertEqual(value, '123.45')
-        
+
 def main():
     from optparse import OptionParser
     parser = OptionParser(usage="usage: %prog [options] connection_string")
